```
  _________.__                 __  .__      ____________________ 
 /   _____/|  |   ____  __ ___/  |_|  |__   \______   \______   \
 \_____  \ |  | _/ __ \|  |  \   __\  |  \   |     ___/|       _/
 /        \|  |_\  ___/|  |  /|  | |   Y  \  |    |    |    |   \
/_______  /|____/\___  >____/ |__| |___|  /  |____|    |____|_  /
        \/           \/                 \/                    \/ 
```

Sleuth PR is a pull request automation application to help developers waste less time in the PR process.

- Automate merges based on your team's requirements
- Run standalone or embed in another Django application
- Apache v2 license


Quickstart Guide
----------------

- Install [re2](https://github.com/google/re2/tree/2020-10-01)
- python3.8 -m venv venv && source venv/bin/activate
- cp config/dev/env.template config/dev/env # and edit with the correct values
- pip install -r requirements.txt
- make run

Release Guide
-------------

- Tag as vMAJOR.MINOR.PATCH (either via the CLI or GitHub UI)
- Sit back and relax by watching some [Sleuth TV](https://www.youtube.com/channel/UCmIIOHKgJnGQruIVD_Zx71g)

Contributors
------------

- Deni1111
